@@ -26,7 +26,7 @@ ExampleWindow::ExampleWindow()
   set_border_width(12);
 
   // Button
-  m_button.set_image_from_icon_name("go-home-symbolic");
+  m_button.set_image_from_icon_name("go-home-symbolic", Gtk::ICON_SIZE_BUTTON, true);
   m_button.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_button_clicked));
 
   // Entries
